@@ -10,9 +10,8 @@ use strict;
 use warnings;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
-use Term::ANSIColor qw/color/;
 
-our $VERSION = 0.06;
+our $VERSION = 0.007;
 
 sub branch {
     my ($self, $options) = @_;
@@ -60,43 +59,10 @@ sub branch {
         $branch .= '...';
     }
 
-    my ($len, $status) = status($type);
     return $self->surround(
-        $len + length $type . $branch,
+        length $type . $branch,
         $self->colour('branch_label') . $type
         . $self->colour('branch') . $branch
-        . $status
-    );
-}
-
-sub status {
-    my ($type) = @_;
-    return (0, '') if $type ne 'git ';
-
-    my %status = (
-        staged    => 0,
-        unstaged  => 0,
-        untracked => 0,
-    );
-    my @status = `git status --porcelain`;
-    for my $status (@status) {
-        my ($staged, $unstaged) = $status =~ /^(.)(.)/;
-        $status{staged}++ if $staged ne '?' && $staged ne ' ';
-        $status{unstaged}++ if $unstaged ne '?' && $unstaged ne ' ';
-        $status{untracked}++ if $staged eq '?' && $unstaged eq '?';
-    }
-
-    my @chars = (' ', '①','②','③','④','⑤','⑥','⑦','⑧','⑨','⑩','⑪','⑫','⑬','⑭','⑮','⑯','⑰','⑱','⑲','⑳','㉑','㉒','㉓','㉔','㉕','㉖','㉗','㉘','㉙','㉚','㉛','㉜','㉝','㉞','㉟', '∞');
-    my $str = '';
-    $str .= ' ' . color('green') . ($chars[$status{staged}   ] || $chars[36]) if $status{staged};
-    $str .= ' ' . color('red'  ) . ($chars[$status{unstaged} ] || $chars[36]) if $status{unstaged};
-    $str .= ' ' . color('white') . ($chars[$status{untracked}] || $chars[36]) if $status{untracked};
-
-    return (
-        (! $status{staged}    ? 0 : $status{staged}    > 20 ? 3 : 2) +
-        (! $status{unstaged}  ? 0 : $status{unstaged}  > 20 ? 3 : 2) +
-        (! $status{untracked} ? 0 : $status{untracked} > 20 ? 3 : 2),
-        $str
     );
 }
 
@@ -124,7 +90,7 @@ App::PS1::Plugin::Branch - Adds the current branch to prompt
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Branch version 0.06.
+This documentation refers to App::PS1::Plugin::Branch version 0.007.
 
 =head1 SYNOPSIS
 
@@ -151,10 +117,6 @@ Returns the full path for the git executable
 
 Returns the full path for the cvs executable
 
-=head3 C<status ()>
-
-Adds a status of the number of changes present for git repositories.
-
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
