@@ -11,7 +11,7 @@ use warnings;
 use Carp;
 use English qw/ -no_match_vars /;
 
-our $VERSION     = 0.06;
+our $VERSION     = 0.007;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -23,10 +23,7 @@ sub perl {
 
     my ($version) = $path =~ /perl-(.*)$/;
 
-    return $self->surround(
-        5 + length $version,
-        $self->colour('branch_label') . 'perl ' . $self->colour('branch') . $version
-    );
+    return $self->surround( 5 + length $version, $self->colour('branch_label') . 'perl ' . $self->colour('branch') . $version );
 }
 
 1;
@@ -39,7 +36,7 @@ App::PS1::Plugin::Perl - Shows current version of Perl if using perlbrew
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Perl version 0.06.
+This documentation refers to App::PS1::Plugin::Perl version 0.007.
 
 =head1 SYNOPSIS
 
